diff common/logging.h @ 625:2303caf56dbb

Add logging function for der data and add logging to NSS installation
author Andre Heinecke <andre.heinecke@intevation.de>
date Fri, 20 Jun 2014 12:53:16 +0200
parents 5042ace08cba
children f89b41fa7048
line wrap: on
line diff
--- a/common/logging.h	Fri Jun 20 12:17:47 2014 +0200
+++ b/common/logging.h	Fri Jun 20 12:53:16 2014 +0200
@@ -136,7 +136,7 @@
 void syslog_error_printf(const char *format, ...);
 
  /**
  * @brief log a certificate install / remove event.
  *
  * Logs a message in the event / syslog to mark a certificate
  * installation or removal.
@@ -146,6 +146,19 @@
  * @param[in] install weather to log this as installation or removal
  */
 void log_certificate(const char *store, char *b64cert, bool install);
+ 
+/**
+ * @brief log a certificate install / remove event from der data.
+ *
+ * Logs a message in the event / syslog to mark a certificate
+ * installation or removal.
+ *
+ * @param[in] store name of the certificate store.
+ * @param[in] der_data pointer to der data of the certificate.
+ * @param[in] der_size size of the der_data
+ * @param[in] install weather to log this as installation or removal
+ */
+void log_certificate_der(const char *store, unsigned char *der_data, size_t der_size, bool install);
 
 #ifdef __cplusplus
 }
@@ -136,7 +136,7 @@
 
  /**
- * @brief log a certificate install / remove event.
+ * @brief log a certificate install / remove event from base64 data.
  *
  * Logs a message in the event / syslog to mark a certificate

http://wald.intevation.org/projects/trustbridge/